**Example 1: 修改资产信息**

修改资产信息

Input: 

```
tccli dasb ModifyDevice --cli-unfold-argument  \
    --GroupIdSet 1 \
    --Id 1 \
    --Port 1
```

Output: 
```
{
    "Response": {
        "RequestId": "xx"
    }
}
```

